"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = RefreshAuthorized;
exports.RefreshRoutes = RefreshRoutes;

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _react = _interopRequireDefault(require("react"));

var _router = require("dva/router");

var _Container = _interopRequireDefault(require("../Container"));

var _UserContainer = _interopRequireDefault(require("../UserContainer"));

var _Exception = require("../Exception");

var _utils = require("../../global/router/utils");

/**
 * @author vuchan<givingwu@gmail.com>
 * 1. 当登陆和登出时，需要刷新路由
 *    a little same as `antd/pro/components/Authorized`, but less and simpler.
 * 2. `checkAuthority()` one more time.
 */
function RefreshAuthorized(_ref) {
  var menus = _ref.menus,
      routes = _ref.routes,
      routers = _ref.routers,
      outerRoutes = _ref.outerRoutes,
      outerRouters = _ref.outerRouters,
      redirect = _ref.redirect;
  // at first, we must check out the authority `cookie` before `render` be called
  // in our project, it called `fw-erp` for server authorization
  var authorized = (0, _utils.checkAuthority)();

  if (!authorized) {
    // maybe it will have customization redirect path that depends on diff requirements and diff project.
    // so we provide this API if `redirect` does not given we redirect to `admin.${domain}.cn/user/login` as default.
    if (/^https?/.test(redirect)) {
      return window.location.href = redirect;
    } // otherwise like `/#/user/login` will render next as below `RenderOuterContainer` -> `Redirect`

  }

  var RenderContainer = function RenderContainer(props) {
    return _react.default.createElement(_Container.default, (0, _extends2.default)({
      localMenus: menus,
      routers: routers,
      redirect: redirect
    }, props), _react.default.createElement(_router.Switch, null, routes.map(function (_ref2) {
      var path = _ref2.path;
      return _react.default.createElement(_router.Route, {
        exact: true,
        key: path,
        path: path,
        component: routers[path].component
      });
    }), _react.default.createElement(_router.Redirect, {
      exact: true,
      from: "/",
      to: (0, _utils.getBashRedirect)(routes)
    }), _react.default.createElement(_router.Route, {
      render: _Exception.NotFound
    })));
  };

  var RenderOuterContainer = function RenderOuterContainer(props) {
    return (// render outer content
      _react.default.createElement(_UserContainer.default, (0, _extends2.default)({
        routers: outerRouters
      }, props), _react.default.createElement(_router.Switch, null, outerRoutes.map(function (_ref3) {
        var path = _ref3.path;
        return _react.default.createElement(_router.Route, {
          exact: true,
          key: path,
          path: path,
          component: outerRouters[path].component
        });
      }), _react.default.createElement(_router.Redirect, {
        exact: true,
        from: "/",
        to: authorized ? (0, _utils.getBashRedirect)(outerRoutes) : redirect
      }), _react.default.createElement(_router.Route, {
        render: _Exception.NotFound
      })))
    );
  };

  {
    /* Take care of that switch only match path once from a slash '/', at 'https://github.com/ReactTraining/react-router/blob/master/packages/react-router/modules/matchPath.js#L28' */
  }
  return _react.default.createElement(_router.Switch, null, _react.default.createElement(_router.Route, {
    exact: true,
    path: "/403",
    render: _Exception.UnAuthorized
  }), _react.default.createElement(_router.Route, {
    exact: true,
    path: "/404",
    render: _Exception.NotFound
  }), _react.default.createElement(_router.Route, {
    exact: true,
    path: "/500",
    render: _Exception.ServerError
  }), _react.default.createElement(_router.Route, {
    path: "/user",
    component: RenderOuterContainer
  }), _react.default.createElement(_router.Route, {
    path: "/",
    render: authorized ? RenderContainer : RenderOuterContainer
  }), _react.default.createElement(_router.Route, {
    render: _Exception.NotFound
  }));
}

function RefreshRoutes() {}