"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = RouterContainer;

var _typeof2 = _interopRequireDefault(require("@babel/runtime/helpers/typeof"));

var _react = _interopRequireDefault(require("react"));

var _router = require("dva/router");

var _antd = require("antd");

var _zh_CN = _interopRequireDefault(require("antd/lib/locale-provider/zh_CN"));

var _RefreshRoutes = _interopRequireDefault(require("../../components/RefreshRoutes"));

var _utils = require("./utils");

var ConnectedRouter = _router.routerRedux.ConnectedRouter;
/**
 * RouterContainer
*  @author vuchan<givingwu@gmail.com>
 * @param {Object} ConfigOptions
 *  @prop routes  External routes configuration
 *  @prop menus   External menus
 *  @prop redirect
 *  @prop outerRoutes Outer router, like '/', '/user/*' etc.
 *  @prop useDva  // use dva for lazyLoad or use reactLoadable
 */

function RouterContainer(_ref) {
  var app = _ref.app,
      history = _ref.history,
      menus = _ref.menus,
      routes = _ref.routes,
      outerRoutes = _ref.outerRoutes,
      redirect = _ref.redirect;
  // If we cannot got valid parameters from the 1th param which be deconstructed
  // We will fallback to get those from app instance of `dva`
  if (!routes) routes = app.routes;
  if (!menus) menus = app.menus || [];
  if (!redirect) redirect = app.redirect || '';
  if (!outerRoutes) outerRoutes = app.outerRoutes || []; // only integrates local menus when `development` env

  if (process.env.NODE_ENV === 'development') {
    if (!routes || !routes.length) {
      throw new Error("You must pass an valid array for routes not is ".concat(routes, ", ").concat((0, _typeof2.default)(routes)));
    }
  } else {
    menus = [];
  } // at first, we must check out the authority `cookie` before `render` be called


  var authorized = (0, _utils.checkAuthority)();

  if (!authorized) {
    // maybe it will has customization redirect path that depends on diff requirement and diff project.
    // so we provide this API if `redirect` does not given we redirect to `geneLoginUrl()` as default.
    if (/^https?/.test(redirect)) {
      return window.location.href = redirect;
    } // otherwise like `/#/user/login` will render next as below `renderUserContainer` -> `Redirect`

  }

  var routers = (0, _utils.dvaLazyLoad)(app, routes);
  var outerRouters = (0, _utils.dvaLazyLoad)(app, outerRoutes);
  return _react.default.createElement(_antd.LocaleProvider, {
    locale: _zh_CN.default
  }, _react.default.createElement(ConnectedRouter, {
    history: history
  }, _react.default.createElement(_RefreshRoutes.default, {
    routes: routes,
    outerRoutes: outerRoutes,
    routers: routers,
    outerRouters: outerRouters,
    menus: menus,
    redirect: redirect
  })));
}