"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.registerModel = registerModel;
exports.getMenuData = getMenuData;
exports.flattenMenuData = flattenMenuData;
exports.formatMenus = formatMenus;
exports.MENUS = exports.flattenChildren = exports.loadableLazyLoad = exports.dvaLazyLoad = exports.lazyLoadComponent = exports.dynamicWrapper = exports.lazyLoadModels = exports.redirectToPath = exports.getBashRedirect = exports.removeAuthority = exports.checkAuthority = void 0;

var _objectWithoutProperties2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutProperties"));

var _objectSpread2 = _interopRequireDefault(require("@babel/runtime/helpers/objectSpread"));

var _promise = _interopRequireDefault(require("@babel/runtime/core-js/promise"));

var _toConsumableArray2 = _interopRequireDefault(require("@babel/runtime/helpers/toConsumableArray"));

var _react = _interopRequireWildcard(require("react"));

var _dynamic = _interopRequireDefault(require("dva/dynamic"));

var _spin = _interopRequireDefault(require("antd/lib/spin"));

require("antd/lib/spin/style/css");

var _const = require("../const");

var _utils = require("../../utils");

var _Cookie = require("../../utils/helpers/Cookie");

var _utils2 = require("../../http/utils");

// import Loadable from 'react-loadable';  // https://github.com/jamiebuilds/react-loadable
// import { routerRedux } from 'dva/router';
// https://dvajs.com/api/#dva-dynamic

/**
 * Checkout Authority Cookie
 */
var checkAuthority = function checkAuthority() {
  return (0, _Cookie.getCookie)(_const.AUTH_NAME);
};
/**
 * Remove Authority Cookie
 */


exports.checkAuthority = checkAuthority;

var removeAuthority = function removeAuthority() {
  return (0, _Cookie.delCookie)(_const.AUTH_NAME);
};

exports.removeAuthority = removeAuthority;

var getBashRedirect = function getBashRedirect(routes) {
  // According to the url parameter to redirect
  // 这里是重定向的,重定向到 url 的 redirect 参数所示地址
  var urlParams = new URL(window.location.href);
  var redirect = urlParams.searchParams.get('redirect'); // Remove the parameters in the url

  if (redirect) {
    urlParams.searchParams.delete('redirect');
    window.history.replaceState(null, 'redirect', urlParams.href);
  }

  return redirect || routes[0] && routes[0].path;
};

exports.getBashRedirect = getBashRedirect;

var redirectToPath = function redirectToPath(redirect) {
  if (!redirect) redirect = (0, _utils2.geneLoginUrl)();
  var location = window.location;

  if ((0, _utils.isUrl)(redirect)) {
    return location.replace(redirect);
  } else {
    // get location pathname
    var pathname = location.hash && location.hash.replace(/\#?/, ''); // add the parameters in the url

    if (pathname && /\/.+/.test(pathname)) {
      // return routerRedux.push(pathname ? `${redirect}?redirect=${pathname}` : redirect)
      // return window.history.replaceState(null, 'login', redirect)
      return location.href = "".concat(redirect, "?redirect=").concat(pathname);
    }

    return location.href = redirect;
  }
};

exports.redirectToPath = redirectToPath;
var cached = {};

function registerModel(app, model) {
  model = model.default || model;

  if (!cached[model.namespace]) {
    app.model(model);
    cached[model.namespace] = 1;
  }
}

var lazyLoadModels = function lazyLoadModels(app, models) {
  if (!Array.isArray(models)) {
    models = [models];
  } // Execute all promises


  models = models.map(function (model) {
    return model();
  }); // return `Promise.all`

  return _promise.default.all.apply(_promise.default, (0, _toConsumableArray2.default)(models)).then(function (ret) {
    ret.forEach(function (m) {
      m = m.default || m;
      (Array.isArray(m) ? m : [m]).map(function (_) {
        return registerModel(app, _);
      });
    });
  });
}; // wrapper of dynamic,
// lazyLoad component and add loading effect


exports.lazyLoadModels = lazyLoadModels;

var dynamicWrapper = function dynamicWrapper(app, models, component) {
  // register models
  // support require('model'), () => import(model) and () => [import(model), import(model1)]
  if (models) {
    if ((0, _utils.isPlainObject)(models)) {
      // for CMD `require('module')`
      registerModel(app, models);
    } else if (typeof models === 'function') {
      // for async load `() => [import('module1'), import('module2')]`
      return lazyLoadModels(app, models).then(function () {
        return lazyLoadComponent((0, _utils.isFunction)(component) ? component() : component);
      });
    } else if (typeof models === 'string') {// for string path
      // 因为这里使用全局的上下文，所以这样相对位置的引用会比较尴尬
      // 推荐在传入 model 的时候包上绝对路径
      // registerModel(models.includes('/') ? require(models) : require(`../models/${models}`))
    }
  } // works for () => require('module') `CMD`
  // transformed by babel-plugin-dynamic-import-node-sync


  if (component.toString().indexOf('.then(') < 0) {
    return function (props) {
      return (0, _react.createElement)(component().default, (0, _objectSpread2.default)({}, props));
    };
  } // webpack lazy load `() => ('module')`
  // () => import('module')


  return lazyLoadComponent((0, _utils.isFunction)(component) ? component() : component);
};

exports.dynamicWrapper = dynamicWrapper;

var Loadable = function Loadable(obj) {
  return obj;
};

var lazyLoadComponent = function lazyLoadComponent(component) {
  return Loadable({
    // loader: component,
    loader: function loader() {
      return component().then(function (raw) {
        var Component = raw.default || raw;
        return function (props) {
          return (0, _react.createElement)(Component, (0, _objectSpread2.default)({}, props) // routerData: routerDataCache,
          );
        };
      });
    },
    delay: 300,
    loading: Loading
  });
};

exports.lazyLoadComponent = lazyLoadComponent;

function Loading(props) {
  if (props.error) {
    return _react.default.createElement("div", null, "Error! ", _react.default.createElement("button", {
      onClick: props.retry
    }, "Retry"));
  } else if (props.timedOut) {
    return _react.default.createElement("div", null, "Taking a long time... ", _react.default.createElement("button", {
      onClick: props.retry
    }, "Retry"));
  } else if (props.pastDelay) {
    return _react.default.createElement(_spin.default, {
      size: "large",
      className: "global-spin"
    });
  } else {
    return null;
  }
}

var dvaLazyLoad = function dvaLazyLoad(app, routes) {
  return routes.reduce(function (config, _ref) {
    var path = _ref.path,
        models = _ref.models,
        component = _ref.component,
        restConfig = (0, _objectWithoutProperties2.default)(_ref, ["path", "models", "component"]);

    if ((0, _utils.isFunction)(component) || (0, _utils.isFunction)(models)) {
      config[path] = {
        path: path,
        component: (0, _dynamic.default)((0, _objectSpread2.default)({
          app: app,
          models: models,
          component: component,
          LoadingComponent: function LoadingComponent() {
            return _react.default.createElement(_spin.default, {
              size: "large",
              className: "global-spin"
            });
          }
        }, restConfig))
      };
    } else {
      config[path] = {
        path: path,
        models: models,
        component: component
      };
    }

    return config;
  }, {});
};

exports.dvaLazyLoad = dvaLazyLoad;

var loadableLazyLoad = function loadableLazyLoad(app, routes) {
  return routes.reduce(function (config, _ref2) {
    var path = _ref2.path,
        models = _ref2.models,
        component = _ref2.component;

    if ((0, _utils.isFunction)(component)) {
      config[path] = {
        path: path,
        component: dynamicWrapper(app, models, component)
      };
    } else {
      config[path] = {
        path: path,
        component: component
      };
    }

    return config;
  }, {});
};
/**
 * flattenChildren
 * @param {Array<Object>} arr
 */


exports.loadableLazyLoad = loadableLazyLoad;

var flattenChildren = function flattenChildren(arr) {
  var flattened = [];
  arr.forEach(function (item) {
    if (item.children && item.children.length) {
      flattened.push.apply(flattened, (0, _toConsumableArray2.default)(flattenChildren(item.children)));
    } else {
      flattened.push(item);
    }
  });
  return flattened;
};
/**
 * getMenuData
 * @desc 向当前业务层 菜单中注入 开发环境 菜单
 *  1. server 会返回原有的 oldMenus 菜单数据，需要格式化
 *  2. 新的菜单数据 newMenus 需要被格式化加入 菜单
 * @param {Array<Menus>} oldMenus
 * @return {Function? Array<RouteConfig> => }
 * @example
 *  const oldMenus = [{name: 'a', path: 'a', children: [{ name: 'b', path: 'b' }]}]
 *  const newMenus = [{name: 'c', path: 'c', children: [{ name: 'd', path: 'd' }]}]
 *  const menusData = @injectMenus(newMenus)(oldMenus)
 */


exports.flattenChildren = flattenChildren;
var MENUS = [];
exports.MENUS = MENUS;

function getMenuData() {
  var oldMenus = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];
  var newMenus = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];
  var newMenuData = formatMenus(newMenus);
  var oldMenuData = formatMenus(oldMenus || []);
  return exports.MENUS = MENUS = (0, _toConsumableArray2.default)(oldMenuData).concat((0, _toConsumableArray2.default)(newMenuData));
}
/**
 * flattenMenuData
 * @desc 递归展开所有菜单数据
 * @author antd-pro
 * @param {Array<Menu>} menus
 * @return {Object<Menu>}
 * @example
 *  flattenMenuData(formatMenus(menus)) // { '/a': Menu1, '/ab': Menus11, '/abc': Menus111, '/b': Menu2 }
 */


function flattenMenuData(menus) {
  var keys = {};
  menus.forEach(function (item) {
    if (item.children) {
      keys[item.path] = (0, _objectSpread2.default)({}, item);
      keys = (0, _objectSpread2.default)({}, keys, flattenMenuData(item.children));
    } else {
      keys[item.path] = (0, _objectSpread2.default)({}, item);
    }
  });
  return keys;
}
/**
 * formatMenus
 * @desc 格式化菜单数据，并支持`domain`属性
 * @inspired antd-pro
 * @param {Array<Object>} menu
 * @param {String} parentPath   上一节点路径
 * @return {Array<Menu>}   菜单路由
 * @example
 *  const menus = [{
 *    "name":"基础管理系统",
 *    "icon":"dashboard",
 *    "path":"admin",
 *    "domain":"admin.feewee.cn",
 *    "children":[{
 *      "name":"系统管理",
 *      "icon":"setting",
 *      "path":"system"
 *    }]
 *  }]
 *
 *  const menuRoutes = formatMenus(menus); //[{"name":"基础管理系统","icon":"dashboard","path":"/admin","domain":"admin.feewee.cn","children":[{"name":"系统管理","icon":"setting","path":"/admin/system"}]}]
 */


function formatMenus(menu) {
  var parentPath = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : '/';
  var parentDomain = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;
  return menu.map(function (item) {
    var path = item.path,
        domain = item.domain;

    if (!(0, _utils.isUrl)(path)) {
      path = parentPath + item.path; // only add the host in `development` env

      if (parentDomain) {
        if (process.env.NODE_ENV === 'development') {
          parentDomain = window.location.host;
        }

        path = window.location.protocol + '//' + parentDomain + '/#' + path;
      }
    }

    var result = (0, _objectSpread2.default)({}, item, {
      path: path
    });

    if (item.children) {
      result.children = formatMenus(item.children, "".concat(parentPath).concat(item.path, "/"), domain);
    }

    return result;
  });
}