"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _typeof2 = _interopRequireDefault(require("@babel/runtime/helpers/typeof"));

var _promise = _interopRequireDefault(require("@babel/runtime/core-js/promise"));

var http = _interopRequireWildcard(require("axios"));

var _utils = _interopRequireDefault(require("axios/lib/utils"));

var _utils2 = require("./utils");

var _querystring = require("querystring");

/**
 * 挂载 axios.postForm() 方法
 * 挂载 axios.postJSON() 方法
 */
var Axios = http.Axios;
var ContentTypes = [{
  'Content-Type': 'application/json;charset=utf-8'
}, {
  'Content-Type': 'application/x-www-form-urlencoded;charset=utf-8'
}]; // 参见[defaults.transformRequest[0]] https://github.com/axios/axios/blob/master/lib/defaults.js

['postJSON', 'postForm'].forEach(function (method, index) {
  Axios.prototype[method] = function (url, data, config) {
    return this.request(_utils.default.merge(config || {}, {
      method: 'post',
      url: url,
      data: method === 'postForm' ? window.URLSearchParams ? new URLSearchParams(data) : (0, _querystring.stringify)(data) : data
    }, {
      headers: ContentTypes[index]
    }));
  };
});
/**
 * 为什么这里需要 http.create() ?
 * 因为上面往实例中重新挂载了新的方法，所以这里需要调用工厂方法重新绑定 Axios.prototype 对象
 */

var axios = http.create({
  timeout: 60 * 1000 * 2
});
/**
 * [参见0](https://github.com/axios/axios/blob/master/lib/adapters/xhr.js#L67) // xhr request source code
 * [参见1](https://github.com/axios/axios/blob/master/lib/core/settle.js#L18) // promise resolve settle
 * [参见2](https://github.com/axios/axios/blob/master/lib/core/createError.js#L15) // how axios returns an error
 * [参见3](https://github.com/axios/axios/blob/master/lib/core/enhanceError.js#L13) // enhance Error 返回错误并挂载 request\response\config 到 Error 对象
 * [usage](./README.md#L5~L10)
 */

/**
 * TODO:
 *  1. 在发起请求前，检查本地是否包含指定的 cookie `${config.cookieName ?: string}` or 'fw-erp'
 *  如果是用户`login`,`logout`,`register`,`forgotPswd`等操作，则应该忽略检查。
 *  所以需要一个`config.ignorePaths ?: array` or `['login', 'logout', ...]`
 *
 *  2. 再发起请求时候默认约定加上 `gateway` 转发的地址，即 prefix: '/api' 网关代理
 *  为了保证和以前兼容，加了 prefix 的则不需要添加，支持自定义 prefix: http.get(url, { prefix: '/custom' })
 *  检测如果是完整 http url 路径，/https?\:/ 则直接发起请求不需要 prefix
 *  如果不需要自动添加 prefix 则 http.get(url, { prefix: false }) 取消自动添加prefix
 */

axios.interceptors.request.use(function (config) {
  if (config.debug) {
    console.log('request => config ====================================');
    console.log(config);
    console.log('request => config ====================================');
  } // if u add new Chainable promise or other interceptor
  // You have to return `config` inside of a request
  // otherwise u will get a very confusing error
  // and spend 5mins at least to debug that.


  return config;
}, function (error) {
  return _promise.default.reject(error).then(function (error) {
    (0, _utils2.showErrorMsg)(error);
    console.dir(error);
  });
});
axios.interceptors.response.use(function (response) {
  // handle server response error
  var data = response.data,
      status = response.status,
      statusText = response.statusText,
      _response$config = response.config,
      config = _response$config === void 0 ? {} : _response$config; // 参见0 参见1
  // if it is a external request, just return its data

  if (config.external) {
    return data;
  } else {
    // if no data returns from server, do nothing
    // and just return empty data object
    if (data) {
      var code = data.code,
          success = data.success,
          serverData = data.data,
          result = data.result; // 默认当 success && code === 0 的时候
      // 理解为下游不需要手动处理 data.code，所以直接返回 data

      if (success && code === 0) {
        return serverData;
      } // 需要自己处理成功后的code
      // 或者 code 不为0的情况
      else if (config.allData || success && code !== 0) {
          return data;
        } else {
          var message = '请求返回异常'; // 不交由下游处理

          if (!config.handleError) {
            (0, _utils2.showErrorMsg)(message = (0, _utils2.getErrorMsg)(data, status, result || statusText));
          }

          return _promise.default.reject({
            message: message,
            code: code,
            data: data
          });
        }
    }
    /*  else {
     // 这里的异常不能吃！！！
     return Promise.reject(new Error('Data is not a valid object'))
     } */

  }
}, function (error) {
  // handle http status code error `401|403|500`
  var _error$config = error.config,
      config = _error$config === void 0 ? {} : _error$config,
      code = error.code,
      _error$request = error.request,
      request = _error$request === void 0 ? {} : _error$request,
      _error$response = error.response,
      response = _error$response === void 0 ? {} : _error$response; // 参见1

  if (error && (config || request || response)) {
    var data = response.data,
        status = response.status,
        statusText = response.statusText,
        respCode = response.code; // 参见0

    var errorMsg = '请求发生错误';
    var errorCode = code || respCode || status;

    if (errorCode && errorCode === 'ECONNABORTED') {
      errorMsg = (0, _utils2.getErrorMsg)(data, status || 504, statusText);
    } else {
      errorMsg = (0, _utils2.getErrorMsg)(data, status, statusText);
    } // 不交由下游处理


    if (!config.handleError) {
      if (status) {
        if (status === 401 && data && (0, _typeof2.default)(data) === 'object') {
          //unauthorized
          (0, _utils2.handleUnauthorized)(errorCode || status, data);
        } else {
          (0, _utils2.showErrorMsg)(errorCode || status, errorMsg);
        }
      }
    }

    if (errorMsg) error.message = errorMsg;
    if (errorCode) error.code = errorCode;
  } else {
    (0, _utils2.showErrorMsg)('Unknown Error', error);
  }

  return _promise.default.reject(error);
});
var _default = axios;
exports.default = _default;