"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = Observer;

/**
 * @Class Observer
 * @author VuChan
 * @constructor
 * @return {Object} Observer Design Pattern Implementation
 */
function Observer() {
  this.events = {};
}
/**
 * observer.on('eventName', function listener() {})
 * @param  {String} eventName
 * @param  {Function} listener
 * @return {handlers<Array>}
 */


Observer.prototype.on = function (eventName, listener) {
  if (!this.events[eventName]) {
    this.events[eventName] = [listener];
  } else {
    this.events[eventName].push(listener);
  }

  return this.events[eventName];
};
/**
 * observer.off('eventName', function listener() {})
 * @param  {String} eventName
 * @param  {Function} listener
 * @return {Boolean|Null}
 */


Observer.prototype.off = function (eventName, listener) {
  if (eventName) {
    var handlers = this.events[eventName];

    if (handlers && handlers.length) {
      if (listener) {
        return handlers = handlers.filter(function (handler) {
          return handler === listener;
        });
      } else {
        delete this.events[eventName];
        return true;
      }
    }
  } else {
    this.events = {};
  }
};
/**
 * observer.trigger('eventName', data1, data2, ...dataN)
 * @param  {String} eventName
 * @param  {Array}  data
 * @return {Boolean}
 */


Observer.prototype.trigger = function (eventName) {
  for (var _len = arguments.length, data = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
    data[_key - 1] = arguments[_key];
  }

  var handlers = this.events[eventName];

  if (handlers) {
    handlers.forEach(function (handler) {
      return handler.apply(null, data);
    });
    return true;
  }
};