"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.capitalize = capitalize;
exports.delay = delay;
exports.getSearchParams = exports.getQueryString = exports.checkPropsValue = exports.loadScript = exports.classNames = exports.getRightEnv = exports.getMaxValIgnoreSign = exports.geneRandomNum = exports.random = exports.after = exports.before = exports.toArray = exports.inArray = exports.when = exports.hasProp = exports.isPlainObject = exports.isPhoneNumber = exports.isUrl = exports.isArrayLike = exports.isArray = exports.isUndefined = exports.isEmptyObject = exports.isObject = exports.isFunction = exports.isBoolean = exports.isNumber = exports.isString = exports.PHONE_REG = exports.URL_REG = void 0;

var _objectSpread2 = _interopRequireDefault(require("@babel/runtime/helpers/objectSpread"));

var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));

var _promise = _interopRequireDefault(require("@babel/runtime/core-js/promise"));

var _keys = _interopRequireDefault(require("@babel/runtime/core-js/object/keys"));

var _typeof2 = _interopRequireDefault(require("@babel/runtime/helpers/typeof"));

/**
 * @RegExp
 * @desc Common RegExp
 */
var URL_REG = /(((^https?:(?:\/\/)?)(?:[-;:&=\+\$,\w]+@)?[A-Za-z0-9.-]+(?::\d+)?|(?:www.|[-;:&=\+\$,\w]+@)[A-Za-z0-9.-]+)((?:\/[\+~%\/.\w-_]*)?\??(?:[-\+=&;%@.\w_]*)#?(?:[\w]*))?)$/;
exports.URL_REG = URL_REG;
var PHONE_REG = /^(13[0-9]|14[579]|15[0-3,5-9]|16[6]|17[0135678]|18[0-9]|19[89])\d{8}$/;
/**
 * @utils
 * @desc types check
 */

exports.PHONE_REG = PHONE_REG;

var isString = function isString(str) {
  return typeof str === 'string';
};

exports.isString = isString;

var isNumber = function isNumber(str) {
  return typeof str === 'number';
};

exports.isNumber = isNumber;

var isBoolean = function isBoolean(str) {
  return typeof str === 'boolean';
};

exports.isBoolean = isBoolean;

var isFunction = function isFunction(fn) {
  return typeof fn === 'function';
};

exports.isFunction = isFunction;

var isObject = function isObject(obj) {
  return obj && (0, _typeof2.default)(obj) === 'object';
};

exports.isObject = isObject;

var isEmptyObject = function isEmptyObject(obj) {
  return isObject(obj) && (0, _keys.default)(obj).length;
};

exports.isEmptyObject = isEmptyObject;

var isUndefined = function isUndefined(any) {
  return (0, _typeof2.default)(any) === undefined || any === undefined;
};

exports.isUndefined = isUndefined;

var isArray = function isArray(arr) {
  return Array.isArray(arr) || Object.prototype.toString.call(arr) === '[object Array]';
};

exports.isArray = isArray;

var isArrayLike = function isArrayLike(obj) {
  var length = !!obj && "length" in obj && obj.length;
  return isArray(obj) || length === 0 || typeof length === 'number' && length > 0 && length - 1 in obj;
};

exports.isArrayLike = isArrayLike;

var isUrl = function isUrl(str) {
  return URL_REG.test(str);
};

exports.isUrl = isUrl;

var isPhoneNumber = function isPhoneNumber(str) {
  return PHONE_REG.test(str);
};
/**
 * @author Vuchan
 * @desc same implementation like follow link, but more simpler
 * https://www.npmjs.com/package/is-plain-object
 */


exports.isPhoneNumber = isPhoneNumber;

var isPlainObject = function isPlainObject(obj) {
  return isObject(obj) && Object.prototype.toString.call(obj) === '[object Object]' && obj.constructor === Object;
};
/**
 * @utils
 * @desc helpers
 */

/**
 * hasProp
 * @desc 检测对象是否存在改属性
 * @param {Object} obj
 * @param {String} key
 * @param {Boolean} own
 * @returns {Boolean}
 */


exports.isPlainObject = isPlainObject;

var hasProp = function hasProp(obj, key, own) {
  return isObject(obj) && own ? obj.hasOwnProperty(key) : !isUndefined(obj[key]);
};
/**
 * when
 * @desc when `fulfilled` so do the next by `then`
 * @param {any*} value
 * @param {Function} fulfilled
 * @param {Function} rejected
 */


exports.hasProp = hasProp;

var when = function when(value, fulfilled, rejected) {
  var promise = _promise.default.resolve(value);

  if (arguments.length < 2) {
    return promise;
  }

  return promise.then(fulfilled, rejected);
};
/**
 * inArray
 * @desc To check one `item` in an `array` or not
 * @param {Array} array
 * @param {any*} item
 */


exports.when = when;

var inArray = function inArray(array, item) {
  return isArray(array) ? array.includes && array.includes(item) || ~array.indexOf(item) : null;
};
/**
 * toArray
 * @desc Make the `arguments` to be an real array
 */


exports.inArray = inArray;

var toArray = function toArray() {
  return [].slice.call(arguments);
};
/**
 * capitalize
 * @param {String} str
 */


exports.toArray = toArray;

function capitalize(str) {
  return str.charAt(0).toUpperCase() + str.slice(1);
}
/**
 * before 将函数合并执行，beforeFn先执行，originalFn后执行
 * @author Vuchan
 * @param {*} beforeFn 先执行执行的函数
 * @param {*} originalFn 原函数
 * @param {*} context 上下文this
 * @return any*
 */


var before = function before(originalFn, beforeFn, context) {
  return function () {
    if (beforeFn.apply(context, arguments) === false) return false;
    return originalFn.apply(context, arguments);
  };
};
/**
 * after 将函数合并执行，originalFn先执行，afterFn后执行
 * @author Vuchan
 * @param {*} originalFn 原函数
 * @param {*} afterFn 之后执行的函数
 * @param {*} context 上下文this
 * @return any*
 */


exports.before = before;

var after = function after(originalFn, afterFn, context) {
  return function () {
    var ret = originalFn.apply(context, arguments);
    if (ret === false) return false;
    return afterFn.apply(context, arguments);
  };
};
/**
 * @desc 生成指定范围内随机数 int/float [start, end]
 * @author Vuchan
 * @param {Number}  start
 * @param {Number}  end
 * @param {Boolean|Number} len len == 0 => int | len === N => 带 N 位的小数点，若小数点位数大于随机数，则返回当前长度下最大的完整随机数
 * @return {Number}
 */


exports.after = after;

var random = function random(start, end) {
  var len = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 0;

  if (start !== undefined && typeof +start === 'number') {
    var val = end !== undefined && typeof +end === 'number' ? Math.random() * (end - start + 1) + start : Math.random() * start + 1;

    var _$split = "".concat(val).split('.'),
        _$split2 = (0, _slicedToArray2.default)(_$split, 2),
        int = _$split2[0],
        double = _$split2[1];

    if (isNumber(len)) {
      if (len) {
        return +(int + '.' + "".concat(double).substr(0, len));
      }
    }

    return +int || parseInt(val, 10);
  }
}; // historical reason


exports.random = random;
var geneRandomNum = random;
/**
 * delay 基于Promise的延时调用
 * @author VuChan
 * @param  {Function|Object|Number} fnOrObj
 * @param  {Number} ms=1000
 * @return {Promise}
 */

exports.geneRandomNum = geneRandomNum;

function delay() {
  var fnOrObj = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 1000;
  var ms = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 1000;

  if (typeof fnOrObj === 'number') {
    ms = fnOrObj;
    fnOrObj = null;
  }

  return new _promise.default(function (resolve) {
    var timerId = setTimeout(function () {
      clearTimeout(timerId);
      return resolve(typeof fnOrObj === 'function' ? fnOrObj() : fnOrObj);
    }, ms);
  });
}
/**
 * getMaxValIgnoreSign
 * @author Vuchan
 * @desc 返回所有数中绝对值最大的数（忽略符号）
 * @param  {Number} args
 * @return {Number}
 * @example
 *  getMaxAbsOriVal(-10, 11, -12, 9) // -12
 *  getMaxAbsOriVal(-10.13, 10.12) // -10.13
 */


var getMaxValIgnoreSign = function getMaxValIgnoreSign() {
  for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
    args[_key] = arguments[_key];
  }

  return args.find(function (t) {
    return Math.abs(t) === args.map(function (t) {
      return Math.abs(+t) || 0;
    }).sort(function (a, b) {
      return b - a;
    })[0] && t;
  });
};
/**
 * getRightEnv
 * @author Vuchan
 * @desc 取得当前正确的运行环境 ['test', 'dev', 'prod' = '']
 * @return {String}
 */


exports.getMaxValIgnoreSign = getMaxValIgnoreSign;

var getRightEnv = function getRightEnv() {
  var host = window.location.host;

  if (/^test.*\.feewee\.cn/.test(host)) {
    return 'test';
  }

  if (/^dev.*\.feewee\.cn/.test(host)) {
    return 'dev';
  }

  return '';
};
/**
 * classNames
 * @author Vuchan
 * @desc Combine all arguments to be a classList String.
 * @param {Object} any*
 * @example
 *  classNames({ a: 1, b: 0, c: 'c' })
 *  // "a c"
 *  classNames('a', 'b', 'c', { d: 1, e: 0 })
 *  // "a b c d"
 *  classNames('a', 'b', 'c', { d: 1, e: 0 }, {f: 'e'})
 *  // "a b c d f"
 *  classNames('a', 'b', 'c', { d: 1, e: 0 }, {f: 'e'}, ['g', 'h', {'i': '1', 'j': false }])
 *  // "a b c d f g h i"
 *
 * @return {String} classnames string
 */


exports.getRightEnv = getRightEnv;

var classNames = function classNames() {
  for (var _len2 = arguments.length, args = new Array(_len2), _key2 = 0; _key2 < _len2; _key2++) {
    args[_key2] = arguments[_key2];
  }

  return args.map(function (t) {
    if (Array.isArray(t)) {
      return t.map(function (i) {
        return classNames(i);
      }).join(' ');
    } else if ((0, _typeof2.default)(t) === 'object') {
      return (0, _keys.default)(t).filter(function (k) {
        return t[k];
      }).join(' ');
    } else {
      return typeof t !== 'string' ? t.toString() : t;
    }
  }).join(' ');
};
/**
 * loadScript
 * @author Vuchan
 * @desc lazy load script form a url
 * @param {String} url
 * @return {Promise}
 */


exports.classNames = classNames;

var loadScript = function loadScript(url) {
  var script = document.createElement('script');
  script.type = 'text/javascript';
  script.src = url;
  document.body.appendChild(script);
  return new _promise.default(function (resolve) {
    if (script.readyState) {
      // IE
      script.onreadystatechange = function change() {
        if (script.readyState === 'loaded' || script.readyState === 'complete') {
          resolve();
        }
      };
    } else {
      // Others
      script.onload = function load() {
        resolve();
      };
    }
  });
};
/**
 * checkPropsValue
 * @desc 检查传入对象的属性值，抛出传入的msg或内部默认的错误
 * @author Vuchan
 * @param {Object} obj
 * @param {String} msg
 * @throws Error
 * @return {Boolean}
 */


exports.loadScript = loadScript;

var checkPropsValue = function checkPropsValue(obj, msg) {
  return (0, _keys.default)(obj).reduce(function (status, key) {
    if (!obj[key] && obj[key] !== 0) {
      var error = new Error(msg || "".concat(key, "'s value is required but it's ").concat(obj[key], "!"));
      error.errorKey = key;
      throw error;
    } else {
      return status = true;
    }
  }, true);
};
/**
 * getQueryString
 * @author VuChan
 * @desc  生成链接后面选项参数
 * @param   {String}  url
 * @param   {Object}  Options
 * @return  {Object | null}
 * @design 穷举法:
 *  0. a.com? | a.com?& | a.com?&=&1=2&&
 *  1. a.com?a=1&b=2&c=&d=3
 *  2. a.com?a=1&b=2&c=&d=3/#/hash
 *  3. a.com/#/hash?a=1&b=2&c=&d=3
 *  4. http://mcar.feewee.cn/uploading.html/#/?shopId=5&orderId=231&loanOrderId=59&orderAmount=64900.00&period=36&downPayRate=0.1
 *  5. http://mcar.feewee.cn/uploading.html?shopId=5&orderId=231&loanOrderId=59&orderAmount=64900.00&period=36&downPayRate=0.1/#/
 *  6. http://devwc.feewee.cn/BindingMobileNumber.html?redirect_url=http%3A%2F%2Fdevwc.feewee.cn%2Factivity%2Fshake.html%3FmktId%3D201805070000008%26subType%3D103
 * @requires
 *  1. 减去 hash 符号提取正常的 url
 *  2. 仅提取正确queryString
 *  3. 如果是 number 则需要转化成 number
 * @example
 *  getQueryString(location.href)
 */


exports.checkPropsValue = checkPropsValue;

var getQueryString = function getQueryString() {
  var url = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : window.location.href;
  var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {
    cutHash: true,
    // replace hash `/#/{path}` to be ''
    decoder: decodeURIComponent,
    // self decoder or browser's
    decodeEach: false,
    all: true,
    // need all value whatever it is valid or not
    encode: false,
    // if u need? `false | encodeURLComponent | function`
    placeholder: '' // if value is invalid, so puts the `placeholder`

  };
  var defaultOptions = {
    cutHash: true,
    // replace hash `/#/{path}` to be ''
    decoder: decodeURIComponent,
    // self decoder or browser's
    decodeEach: false,
    all: true,
    // need all value whatever it is valid or not
    encode: false,
    // if u need? `false | encodeURLComponent | function`
    placeholder: '' // if value is invalid, so puts the `placeholder`

  };
  options = (0, _objectSpread2.default)({}, defaultOptions, options);

  var parse = function parse(str) {
    if (!str || !str.trim().length) return null;else {
      if (!~str.indexOf('?') && ~str.indexOf('=') && ~str.indexOf('&')) {
        str = str.split('&').map(function (t) {
          return t.trim();
        }).filter(function (t) {
          return ~t.indexOf('=');
        }).map(function (t) {
          return options.decodeEach ? options.decoder(t) : t;
        });
      } else {
        str = [str];
      }

      if (str.length) {
        return str.reduce(function (r, c) {
          c = c.split('=');
          if (c.length > 2) c = [c.shift(), c.join('=')];

          if (c[0]) {
            if (c[1]) {
              r[c[0]] = +c[1] ? +c[1] : c[1];
            } else {
              r[c[0]] = options.placeholder;
            }
          }

          return r;
        }, {});
      } else {
        return null;
      }
    }
  };

  var str = !options.decodeEach && typeof options.decoder === 'function' ? options.decoder(url) : url; // type check of str value

  if (!str || typeof str !== 'string' || !str.trim()) return null;

  if (options.cutHash) {
    // match this format like -> /#/ | /#/{word}
    str = str.replace(/\/?\#\/(\w*\b)?/, '');
  }

  if (~str.indexOf('?')) {
    // splits `?` only once
    str = str.split('?');

    if (str.length > 2) {
      str = [str.shift(), str.join('?')];
    }

    str = str[1];
  } else {
    // if no any `?` sign returns null
    return null;
  }

  return parse(str);
}; // historical reason


exports.getQueryString = getQueryString;
var getSearchParams = getQueryString;
exports.getSearchParams = getSearchParams;